AppUtils class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getActualMemberName(StringBuffer string) → Tuple2<StringBuffer, bool>
getExceptionMap(String code, String message) → Map
getImageDimensions(String filePath) → Future<Tuple2<int, int>>
Get Width and Height from file
getInitials(String name) → String
  • Build initials with given name.
  • @parameter Name instance of Profile name
  • return initials of the name.
  • getMobileWidthAndHeight(int? originalWidth, int? originalHeight) → Tuple2<int, int>
    Get Width and Height for Mobile
    getNameAndProfileDetails(String jid) → Future<Tuple2<String, ProfileDetails>>
    isMediaExists(String? filePath) → bool
    isMediaFileAvailable(MessageType msgType, ChatMessageModel message) → bool
    isMediaFileNotAvailable(bool isMediaFileAvailable, ChatMessageModel message) → bool
    isNetConnected() → Future<bool>
    returnEmptyStringIfNull(dynamic value) → String