ChatDataModel class

Constructors

ChatDataModel({List<MediaAttachmentsUri>? mediaAttachmentsUri, String? messageContent, String? subject})
ChatDataModel.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
mediaAttachmentsUri ↔ List<MediaAttachmentsUri>?
getter/setter pair
messageContent ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited