SessionManagement class

Constructors

SessionManagement()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setDefaultValues() → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

adminBlocked() → bool
appLastSession() → int
clear() → Future
convSound(bool convSound) → Future
getAuthToken() → String?
getBool(String key) → bool
getChangePinNext() → String
getChatJid() → String?
getCountryCode() → String?
getCurrentChatJID() → String
getEnableBio() → bool
getEnablePin() → bool
getLogin() → bool
getMediaEndPoint() → String?
getMobileNumber() → String?
getMuteNotification() → bool
getName() → String?
getNotificationPopup() → bool
getNotificationSound() → bool
getNotificationUri() → String?
getPassword() → String?
getPin() → String
getString(String key) → String
getSummaryChannelId() → String?
getToken() → String?
getTranslationLanguage() → String
getTranslationLanguageCode() → String
getUserIdentifier() → String
getUserImage() → String?
getUserJID() → String?
getUsername() → String?
getVibration() → bool
getWebLogin() → bool
isAutoDownloadEnable() → bool
isContactSyncDone() → bool
isGoogleTranslationEnable() → bool
isInitialContactSyncDone() → bool
isTrailLicence() → bool
lastPinChangedAt() → int
muteAll(bool muteAll) → Future
onInit() → Future
setAdminBlocked(bool status) → void
setAppSessionNow() → void
setAuthToken(String authToken) → Future
setAutoDownloadEnable(bool status) → void
setBool(String key, bool value) → Future
setChangePinNext(String pin) → Future
setChatJid(String setChatJid) → Future
setCountryCode(String countryCode) → Future
setCurrentChatJID(String chatJID) → void
setCurrentUser(ProData data) → Future
setDontShowAlert() → void
setEnableBio(bool bio) → Future
setEnablePIN(bool pin) → Future
setGoogleTranslationEnable(bool status) → void
setGoogleTranslationLanguage(String language) → void
setGoogleTranslationLanguageCode(String languageCode) → void
setInitialContactSync(bool val) → Future
setIsTrailLicence(bool trail) → dynamic
setKeyChangeFlag(bool change) → Future
setLockAlert(int alertTimeStamp) → void
setLockExpiry(int expiryTimeStamp) → void
setLogin(bool val) → Future
setMediaEndPoint(String mediaEndpoint) → Future
setMuteNotification(bool mute) → Future
setNotificationPopup(bool popup) → Future
setNotificationSound(bool sound) → Future
setNotificationUri(String notificationUri) → Future
setNotificationVibration(bool vibration) → Future
setPIN(String pin) → Future
setString(String key, String value) → Future
setSummaryChannelId(String summaryChannelId) → Future
setSyncDone(bool val) → Future
setToken(String firebaseToken) → Future
setUser(Data data) → Future
setUserIdentifier(String userIdentifier) → Future
setUserImage(String image) → Future
setUserJID(String jid) → Future
setWebChatLogin(bool webChatLogin) → Future
showAlert() → bool
synced() → bool?
vibrationType(String vibrationType) → Future

Constants

prefix → const String